@@ -5,6 +5,7 @@
 #include <unistd.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <signal.h>
 #include <string.h>
 #include <strings.h>
@@ -21,8 +22,11 @@
 #include <errno.h>
 #include <sys/resource.h>
 #include <sys/wait.h>
-#include <openssl/ssl.h>
-#include <openssl/err.h>
+#include "pcre-3.9/pcre.h"
+#ifdef OPENSSL
+ #include <openssl/ssl.h>
+ #include <openssl/err.h>
+#endif
 
 #define _AMAP_INC_H
 #endif
