@@ -1,5 +1,5 @@
 /*
- * AmapCrap v2.7 (c) 2003 by van Hauser / THC <vh@thc.org>
+ * AmapCrap (c) 2003 by van Hauser / THC <vh@thc.org>
  * http://www.thc.org
  *
  * Sends random data to silent ports to illicit a reponse. For use with amap
@@ -12,30 +12,13 @@
  *
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/stat.h>
-#include <sys/time.h>
-#include <sys/resource.h>
-#include <arpa/inet.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <signal.h>
-#include <time.h>
-#include <ctype.h>
-#include <errno.h>
+#include "amap-inc.h"
+#include "amap.h"
 
 #define UNLIMITED   0		// dont change this
 #define ASCII "abcdefghijklmnopqrstuvwxyz "
 
 #ifdef OPENSSL
-#include <openssl/ssl.h>
-#include <openssl/err.h>
 SSL *ssl = NULL;
 SSL_CTX *sslContext = NULL;
 RSA *rsa = NULL;
@@ -53,28 +36,24 @@ int warn = 0;
 
 void help()
 {
-  printf("amapcrap v2.7 (c) 2003 by van Hauser /THC <vh@thc.org>
-
-Syntax: %s [-S] [-u] [-m 0ab] [-M min,max] [-n connects] [-N delay] [-w delay] [-e] [-v] TARGET PORT
-
-Options:
-    -S           use SSL after TCP connect (not usuable with -u)
-    -u           use UDP protocol (default: TCP) (not usable with -c)
-    -n connects  maximum number of connects (default: unlimited)
-    -N delay     delay between connects in ms (default: 0)
-    -w delay     delay before closing the port (default: 250)
-    -e           do NOT stop when a response was made by the server
-    -v           verbose mode
-    -m 0ab       send as random crap:0-nullbytes, a-letters+spaces, b-binary
-    -M min,max   minimum and maximum length of random crap
-    TARGET PORT  target (ip or dns) and port to send random crap
-
-This tool sends random data to a silent port to illicit a response, which can
-then be used within amap for future detection. It outputs proper amap
-appdefs definitions. Note: by default all modes are activated (0:10%%, a:40%%,
-b:50%%). Mode a always sends on line with letters and spaces which end with
-\\r\\n. Visit our homepage at http://www.thc.org
-", prg);
+  printf("amapcrap %s (c) %s by van Hauser/THC <vh@thc.org>\n\n", AMAP_VERSION, AMAP_YEAR);
+  printf("Syntax: %s [-S] [-u] [-m 0ab] [-M min,max] [-n connects] [-N delay] [-w delay] [-e] [-v] TARGET PORT\n\n", prg);
+  printf("Options:\n");
+  printf("    -S           use SSL after TCP connect (not usuable with -u)\n");
+  printf("    -u           use UDP protocol (default: TCP) (not usable with -c)\n");
+  printf("    -n connects  maximum number of connects (default: unlimited)\n");
+  printf("    -N delay     delay between connects in ms (default: 0)\n");
+  printf("    -w delay     delay before closing the port (default: 250)\n");
+  printf("    -e           do NOT stop when a response was made by the server\n");
+  printf("    -v           verbose mode\n");
+  printf("    -m 0ab       send as random crap:0-nullbytes, a-letters+spaces, b-binary\n");
+  printf("    -M min,max   minimum and maximum length of random crap\n");
+  printf("    TARGET PORT  target (ip or dns) and port to send random crap\n\n");
+  printf("This tool sends random data to a silent port to illicit a response, which can\n");
+  printf("then be used within amap for future detection. It outputs proper amap\n");
+  printf("appdefs definitions. Note: by default all modes are activated (0:10%%, a:40%%,\n");
+  printf("b:50%%). Mode 'a' always sends one line with letters and spaces which end with\n");
+  printf("\\r\\n. Visit our homepage at http://www.thc.org\n");
   exit(-1);
 }
 
@@ -107,6 +86,9 @@ int main(int argc, char *argv[])
   struct sockaddr_in target;
   struct hostent *resolv;
   int res = 0;
+#ifdef OPENSSL
+  int err;
+#endif
 #ifndef CYGWIN
   char out[16];
 #endif
@@ -381,8 +363,8 @@ int main(int argc, char *argv[])
 	      printf
 		("\n# Service seems to have crashed from the following trigger:\n");
 	      if (sent_mode == 1) {
-		printf("PROTOCOL_CRASH:%c:1:\"",
-		       sock_type == SOCK_DGRAM ? 'u' : 't');
+		printf("PROTOCOL_CRASH::%s:1:\"",
+		       sock_type == SOCK_DGRAM ? "udp" : "tcp");
 		for (i = 0; i < str_len; i++)
 		  switch (str[i]) {
 		  case '\t':
@@ -399,8 +381,8 @@ int main(int argc, char *argv[])
 		  }
 		printf("\"");
 	      } else {
-		printf("PROTOCOL_CRASH:%c:1:0x",
-		       sock_type == SOCK_DGRAM ? 'u' : 't');
+		printf("PROTOCOL_CRASH::%s:1:0x",
+		       sock_type == SOCK_DGRAM ? "udp" : "tcp");
 		for (i = 0; i < str_len; i++) {
 		  printf("%c",
 			 str[i] / 16 >
@@ -434,8 +416,8 @@ int main(int argc, char *argv[])
 	    printf
 	      ("\n# Service seems to have crashed from the following trigger:\n");
 	    if (sent_mode_old == 1) {
-	      printf("PROTOCOL_CRASH:%c:1:\"",
-		     sock_type == SOCK_DGRAM ? 'u' : 't');
+	      printf("PROTOCOL_CRASH::%s:1:\"",
+		     sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	      for (i = 0; i < str_len_old; i++)
 		switch (str_old[i]) {
 		case '\t':
@@ -452,8 +434,8 @@ int main(int argc, char *argv[])
 		}
 	      printf("\"");
 	    } else {
-	      printf("PROTOCOL_CRASH:%c:1:0x",
-		     sock_type == SOCK_DGRAM ? 'u' : 't');
+	      printf("PROTOCOL_CRASH::%s:1:0x",
+		     sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	      for (i = 0; i < str_len_old; i++) {
 		printf("%c",
 		       str_old[i] / 16 >
@@ -471,8 +453,8 @@ int main(int argc, char *argv[])
 // output function
 	  printf("\n\n# Put this line into appdefs.trig:\n");
 	  if (sent_mode == 1) {
-	    printf("PROTOCOL_NAME:%c:0:\"",
-		   sock_type == SOCK_DGRAM ? 'u' : 't');
+	    printf("PROTOCOL_NAME::%s:0:\"",
+		   sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	    for (i = 0; i < str_len; i++)
 	      switch (str[i]) {
 	      case '\t':
@@ -489,8 +471,8 @@ int main(int argc, char *argv[])
 	      }
 	    printf("\"");
 	  } else {
-	    printf("PROTOCOL_NAME:%c:0:0x",
-		   sock_type == SOCK_DGRAM ? 'u' : 't');
+	    printf("PROTOCOL_NAME::%s:0:0x",
+		   sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	    for (i = 0; i < str_len; i++) {
 	      printf("%c",
 		     str[i] / 16 > 9 ? str[i] / 16 + 87 : str[i] / 16 + 48);
@@ -550,8 +532,8 @@ int main(int argc, char *argv[])
 	  printf
 	    ("\n# Service seems to have crashed from the following trigger:\n");
 	  if (sent_mode == 1) {
-	    printf("PROTOCOL_CRASH:%c:1:\"",
-		   sock_type == SOCK_DGRAM ? 'u' : 't');
+	    printf("PROTOCOL_CRASH::%s:1:\"",
+		   sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	    for (i = 0; i < str_len; i++)
 	      switch (str[i]) {
 	      case '\t':
@@ -568,8 +550,8 @@ int main(int argc, char *argv[])
 	      }
 	    printf("\"");
 	  } else {
-	    printf("PROTOCOL_CRASH:%c:1:0x",
-		   sock_type == SOCK_DGRAM ? 'u' : 't');
+	    printf("PROTOCOL_CRASH::%s:1:0x",
+		   sock_type == SOCK_DGRAM ? "udp" : "tcp");
 	    for (i = 0; i < str_len; i++) {
 	      printf("%c",
 		     str[i] / 16 > 9 ? str[i] / 16 + 87 : str[i] / 16 + 48);
